# theseus_node

## Supporting material
* [gibbs sampling tiny sample from data science from scratch](https://bitbucket.org/Niarfe/book-sample-code/src/master/data_science_from_scratch/chapter20/gibbs_sampling.py)

